# -*- encoding: utf-8 -*-
'''version

Created: 2021/08/23 14:28:01

Contact : lovelacelee@gmail.com

MIT License Copyright (c) 2008~2021 Connard Lee

'''


CLSLQ_Version='1.2.7'
__doc__ = CLSLQ_Version